Struct amazon_sp_reports::models::report_document_encryption_details::ReportDocumentEncryptionDetails
source · [−]pub struct ReportDocumentEncryptionDetails {
pub standard: Standard,
pub initialization_vector: String,
pub key: String,
}Expand description
ReportDocumentEncryptionDetails : Encryption details required for decryption of a report document’s contents.
Fields
standard: StandardThe encryption standard required to decrypt the document contents.
initialization_vector: StringThe vector to decrypt the document contents using Cipher Block Chaining (CBC).
key: StringThe encryption key used to decrypt the document contents.
Implementations